@@ -1,20 +1,18 @@
 """``runway gen-sample cfngin`` command."""
 import logging
 import shutil
-import sys
-from typing import Any  # pylint: disable=W
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, cast
 
 import click
 
 from ... import options
 from .utils import ROOT, TEMPLATES, copy_sample
 
-if sys.version_info.major > 2:
-    from pathlib import Path  # pylint: disable=E
-else:
-    from pathlib2 import Path  # pylint: disable=E
+if TYPE_CHECKING:
+    from ...._logging import RunwayLogger
 
-LOGGER = logging.getLogger(__name__.replace("._", "."))
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__.replace("._", ".")))
 
 
 @click.command("cfngin", short_help="cfngin + troposphere (sampleapp.cfn)")
@@ -22,8 +20,7 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.no_color
 @options.verbose
 @click.pass_context
-def cfngin(ctx, **_):
-    # type: (click.Context, Any) -> None
+def cfngin(ctx: click.Context, **_: Any) -> None:
     """Generate a sample CFNgin project using Blueprints."""
     src = TEMPLATES / "cfngin"
     src_blueprints = ROOT / "blueprints"
@@ -35,9 +32,7 @@ def cfngin(ctx, **_):
 
     blueprints.mkdir()
     LOGGER.debug('copying blueprint from "%s" to "%s"', src_blueprints, blueprints)
-    shutil.copyfile(
-        str(src_blueprints / "__init__.py"), str(blueprints / "__init__.py")
-    )
-    shutil.copyfile(str(src_blueprints / "tf_state.py"), str(tf_state))
+    shutil.copyfile(src_blueprints / "__init__.py", blueprints / "__init__.py")
+    shutil.copyfile(src_blueprints / "tf_state.py", tf_state)
     tf_state.chmod(tf_state.stat().st_mode | 0o0111)
     LOGGER.success("Sample CFNgin module created at %s", dest)
