@@ -2,12 +2,12 @@
 # docs: file://./../../../../docs/source/commands.rst
 import logging
 import subprocess
-from typing import Any, Tuple  # noqa pylint: disable=W
+from typing import Any, Tuple
 
 import click
 
 from ....env_mgr.tfenv import TFEnvManager
-from ....util import DOC_SITE
+from ....utils import DOC_SITE
 from ... import options
 
 LOGGER = logging.getLogger(__name__.replace("._", "."))
@@ -21,8 +21,7 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.no_color
 @options.verbose
 @click.pass_context
-def run(ctx, args, **_):
-    # type: (click.Context, Tuple[str, ...], Any) -> None
+def run(ctx: click.Context, args: Tuple[str, ...], **_: Any) -> None:
     """Run a Terraform command.
 
     Uses the version of Terraform specified in the ".terraform-version" file
