@@ -4,14 +4,23 @@ from __future__ import annotations
 import logging
 from typing import TYPE_CHECKING, Any, Dict, Union
 
+from ...base import HookArgsBaseModel
+
 if TYPE_CHECKING:
     from .....context import CfnginContext
 
 LOGGER = logging.getLogger(__name__)
 
 
+class HookArgs(HookArgsBaseModel):
+    """Hook arguments."""
+
+    client_id: str
+    """The ID of the Cognito User Pool Client."""
+
+
 def update(
-    context: CfnginContext, *, client_id: str, **_: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> Union[Dict[str, Any], bool]:
     """Retrieve/Update the domain name of the specified client.
 
@@ -19,11 +28,14 @@ def update(
     requests. This prehook ensures we have one available, and if not
     we create one based on the user pool and client ids.
 
+    Arguments parsed by
+    :class:`~runway.cfngin.hooks.staticsite.auth_at_edge.domain_updater.HookArgs`.
+
     Args:
         context: The context instance.
-        client_id: The ID of the Cognito User Pool Client.
 
     """
+    args = HookArgs.parse_obj(kwargs)
     session = context.get_session()
     cognito_client = session.client("cognito-idp")
 
@@ -43,7 +55,7 @@ def update(
         return context_dict
 
     try:
-        domain_prefix = (f"{user_pool_hash}-{client_id}").lower()
+        domain_prefix = (f"{user_pool_hash}-{args.client_id}").lower()
 
         cognito_client.create_user_pool_domain(
             Domain=domain_prefix, UserPoolId=user_pool_id
@@ -56,7 +68,7 @@ def update(
 
 
 def delete(
-    context: CfnginContext, *, client_id: str, **_: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> Union[Dict[str, Any], bool]:
     """Delete the domain if the user pool was created by Runway.
 
@@ -65,17 +77,20 @@ def delete(
     error will occur. This process ensures that our generated domain name is
     deleted, or skips if not able to find one.
 
+    Arguments parsed by
+    :class:`~runway.cfngin.hooks.staticsite.auth_at_edge.domain_updater.HookArgs`.
+
     Args:
         context: The context instance.
-        client_id: The ID of the Cognito User Pool Client.
 
     """
+    args = HookArgs.parse_obj(kwargs)
     session = context.get_session()
     cognito_client = session.client("cognito-idp")
 
     user_pool_id = context.hook_data["aae_user_pool_id_retriever"]["id"]
     _, user_pool_hash = user_pool_id.split("_")
-    domain_prefix = (f"{user_pool_hash}-{client_id}").lower()
+    domain_prefix = (f"{user_pool_hash}-{args.client_id}").lower()
 
     try:
         cognito_client.delete_user_pool_domain(
