@@ -165,7 +165,9 @@ class SOARecord:
     def __init__(self, record: ResourceRecordSetTypeDef) -> None:
         """Instantiate class."""
         self.name = record["Name"]
-        self.text = SOARecordText(record.get("ResourceRecords", [{}])[0]["Value"])
+        self.text = SOARecordText(
+            record.get("ResourceRecords", [{"Value": ""}])[0]["Value"]
+        )
         self.ttl = record.get("TTL", 0)
 
 
@@ -582,19 +584,15 @@ class SourceProcessor:
     def __init__(
         self,
         sources: CfnginPackageSourcesDefinitionModel,
-        cache_dir: Optional[Path] = None,
+        cache_dir: Path,
     ) -> None:
         """Process a config's defined package sources.
 
         Args:
-            sources: Package sources from CFNgin config
-                dictionary.
-            cache_dir: Path where remote sources will be
-                cached.
+            sources: Package sources from CFNgin config dictionary.
+            cache_dir: Path where remote sources will be cached.
 
         """
-        if not cache_dir:
-            cache_dir = Path.cwd() / ".runway" / "cache"
         self.cache_dir = cache_dir
         self.package_cache_dir = cache_dir / "packages"
         self.sources = sources
