@@ -1,4 +1,4 @@
-"""Import classes."""
+"""Runway lookup handlers."""
 from . import cfn, ecr, env, random_string, ssm, var
 
 __all__ = ["cfn", "ecr", "env", "random_string", "ssm", "var"]
