@@ -1,20 +1,23 @@
 """Base module for test handlers."""
+from __future__ import annotations
+
 import os
-from typing import Any, Dict, List  # noqa pylint: disable=W
+from typing import TYPE_CHECKING, Any, Dict, List, Union
+
+if TYPE_CHECKING:
+    from ...config.components.runway.base import ConfigProperty
 
 
-class TestHandler(object):
+class TestHandler:
     """Base class for test handlers."""
 
     @classmethod
-    def handle(cls, name, args):
-        # type: (str, Dict[str, Any]) -> None
+    def handle(cls, name: str, args: Union[ConfigProperty, Dict[str, Any]]) -> None:
         """Redefine in subclass."""
         raise NotImplementedError()
 
     @staticmethod
-    def get_dirs(provided_path):
-        # type: (str) -> List[str]
+    def get_dirs(provided_path: str) -> List[str]:
         """Return list of directories."""
         repo_dirs = next(os.walk(provided_path))[1]
         if ".git" in repo_dirs:
