@@ -1,13 +1,18 @@
 """Script test runner."""
+from __future__ import annotations
+
 import logging
 import subprocess
 import sys
 from subprocess import CalledProcessError
-from typing import Any, Dict  # noqa pylint: disable=W
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 from ..._logging import PrefixAdaptor
 from ...tests.handlers.base import TestHandler
 
+if TYPE_CHECKING:
+    from ...config.components.runway.base import ConfigProperty
+
 TYPE_NAME = "script"
 LOGGER = logging.getLogger(__name__)
 
@@ -20,7 +25,9 @@ class ScriptHandler(TestHandler):
             Each command is run in its own subprocess. The working directory
             will be the same as where the 'runway test' command was executed.
 
-    Example:
+    .. rubric:: Example
+    .. code-block: yaml
+
         tests:
           - name: example-test
             type: script
@@ -32,8 +39,7 @@ class ScriptHandler(TestHandler):
     """
 
     @classmethod
-    def handle(cls, name, args):
-        # type: (str, Dict[str, Any]) -> None
+    def handle(cls, name: str, args: Union[ConfigProperty, Dict[str, Any]]) -> None:
         """Perform the actual test."""
         logger = PrefixAdaptor(name, LOGGER)
         for cmd in args["commands"]:
